@@ -1,5 +1,5 @@
 /*
- *     (C) Copyright 2013 Universidad Politécnica de Madrid
+ *     Copyright (c) 2013-2016 CoNWeT Lab., Universidad Politécnica de Madrid
  *
  *     This file is part of Wirecloud Platform.
  *
@@ -19,12 +19,25 @@
  *
  */
 
+/* globals Wirecloud */
+
+
 (function () {
 
     "use strict";
 
     var Theme = function Theme(desc) {
-        Object.defineProperty(this, 'templates', {value: desc});
+        Object.defineProperties(this, {
+            name: {value: desc.name},
+            label: {value: desc.label},
+            baseurl: {value: desc.baseurl},
+            templates: {value: desc.templates}
+        });
+        Object.freeze();
+    };
+
+    Theme.prototype.get_static_url = function get_static_url(path) {
+        return this.baseurl + path;
     };
 
     Wirecloud.ui.Theme = Theme;
