@@ -1,5 +1,5 @@
 /*
- *     Copyright 2013-2014 (c) CoNWeT Lab., Universidad Politécnica de Madrid
+ *     Copyright 2013-2016 (c) CoNWeT Lab., Universidad Politécnica de Madrid
  *
  *     This file is part of Wirecloud Platform.
  *
@@ -19,16 +19,14 @@
  *
  */
 
-/*global gettext, Wirecloud*/
+/* globals Wirecloud */
 
-(function () {
+
+(function (utils) {
 
     "use strict";
 
-    /*************************************************************************
-     * Constructor TODO
-     *************************************************************************/
-/*     {'type': 'formAction', 'mainMsg': "Complete the form ", 'form': windowForm, 'actionElements': [newName, newUrl], 'actionMsgs': ["chose a new name for the Catalogue.", "Complete the url. for example: 'https://wirecloud.conwet.fi.upm.es'"], 'endElement': acceptButton, 'asynchronous': true},*/
+    /*     {'type': 'formAction', 'mainMsg': "Complete the form ", 'form': windowForm, 'actionElements': [newName, newUrl], 'actionMsgs': ["chose a new name for the Catalogue.", "Complete the url. for example: 'https://wirecloud.conwet.fi.upm.es'"], 'endElement': acceptButton, 'asynchronous': true},*/
     var FormAction = function FormAction(tutorial, options) {
 
         this.options = options;
@@ -59,7 +57,7 @@
         }
 
         if (this.mainMsg) {
-            this.mainStep = new Wirecloud.ui.Tutorial.SimpleDescription(tutorial, {'type': 'simpleDescription', 'title': gettext(this.mainTitle), 'msg': gettext(this.mainMsg), 'elem': null});
+            this.mainStep = new Wirecloud.ui.Tutorial.SimpleDescription(tutorial, {'type': 'simpleDescription', 'title': utils.gettext(this.mainTitle), 'msg': utils.gettext(this.mainMsg), 'elem': null});
             this.mainStep.setLast();
         }
     };
@@ -87,38 +85,36 @@
 
     var _activate = function _activate(form) {
         var pos, i, tempElem;
-        
+
         this.element = form;
 
         if (this.mainStep) {
-            //main description
+            // main description
             this.mainStep.wrapperElement.classList.add("activeStep");
 
             // Positions
             pos = form.getBoundingClientRect();
             switch (this.mainPos) {
-                case 'up':
-                    this.mainStep.wrapperElement.style.top = (pos.top - this.mainStep.wrapperElement.offsetHeight - 20) + 'px';
-                    break;
-                case 'right':
-                    this.mainStep.wrapperElement.style.left = (pos.right + 20) + 'px';
-                    break;
-                case 'left':
-                    this.mainStep.wrapperElement.style.left = (pos.left - this.mainStep.wrapperElement.offsetWidth - 20) + 'px';
-                    break;
-                case 'down':
-                    this.mainStep.wrapperElement.style.top = (pos.bottom + 20) + 'px';
-                    break;
-                default:
-                    break;
+            case 'up':
+                this.mainStep.wrapperElement.style.top = (pos.top - this.mainStep.wrapperElement.offsetHeight - 20) + 'px';
+                break;
+            case 'right':
+                this.mainStep.wrapperElement.style.left = (pos.right + 20) + 'px';
+                break;
+            case 'left':
+                this.mainStep.wrapperElement.style.left = (pos.left - this.mainStep.wrapperElement.offsetWidth - 20) + 'px';
+                break;
+            case 'down':
+                this.mainStep.wrapperElement.style.top = (pos.bottom + 20) + 'px';
+                break;
+            default:
+                break;
             }
         }
-        //main action for next step
-        this.endAction = new Wirecloud.ui.Tutorial.UserAction(this.tutorial, {'type': 'userAction', 'msg': this.endElementMsg, 'elem': form.acceptButton.wrapperElement, 'pos': this.endElementPos});
-
+        // main action for next step
+        this.endAction = new Wirecloud.ui.Tutorial.UserAction(this.tutorial, {'type': 'userAction', 'msg': this.endElementMsg, 'elem': form.acceptButton, 'pos': this.endElementPos});
         this.endAction.setNext();
-        var withoutCloseButton = true;
-        this.endAction.activate(withoutCloseButton);
+        this.endAction.activate();
 
         // substeps in this form action
         var activateSubFormAction = function (index) {
@@ -134,21 +130,22 @@
             if (!this.actionElementsValidators[index](this.actionElements[index]()) && !this.subSteps[index].wrapperElement.classList.contains('invalid')) {
                 this.subSteps[index].wrapperElement.classList.add('invalid');
                 this.form.acceptButton.disable();
-                this.invalidcounter ++;
+                this.invalidcounter++;
             } else if (this.actionElementsValidators[index](this.actionElements[index]()) && this.subSteps[index].wrapperElement.classList.contains('invalid')) {
                 this.subSteps[index].wrapperElement.classList.remove('invalid');
-                this.invalidcounter --;
+                this.invalidcounter--;
                 if (this.invalidcounter === 0) {
                     this.form.acceptButton.enable();
                 }
             }
         };
 
-        for (i = 0; i < this.actionElements.length; i ++) {
+        for (i = 0; i < this.actionElements.length; i++) {
             this.subSteps[i] = new Wirecloud.ui.Tutorial.PopUp(this.actionElements[i](), {
                 highlight: false,
                 msg: this.actionMsgs[i],
                 position: this.actionElementsPos[i],
+                user: true,
                 closable: false
             });
 
@@ -166,7 +163,7 @@
             // Activate first step
             activateSubFormAction.call(this, 0);
         }
-        for (i = 0; i < this.disableElems.length; i ++) {
+        for (i = 0; i < this.disableElems.length; i++) {
             this.disableLayer[i] = this.disable(this.disableElems[i]());
         }
         form.cancelButton.disable();
@@ -208,7 +205,7 @@
     FormAction.prototype.destroy = function destroy() {
         var i;
 
-        for (i = 0; i < this.disableLayer.length; i ++) {
+        for (i = 0; i < this.disableLayer.length; i++) {
             this.layer.removeChild(this.disableLayer[i]);
         }
         for (i = 0; i < this.subSteps.length; i++) {
@@ -225,8 +222,6 @@
         }
     };
 
-    /*************************************************************************
-     * Make Anchor public
-     *************************************************************************/
     Wirecloud.ui.Tutorial.FormAction = FormAction;
-})();
+
+})(Wirecloud.Utils);
