@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2008-2014 CoNWeT Lab., Universidad Politécnica de Madrid
+# Copyright (c) 2008-2017 CoNWeT Lab., Universidad Politécnica de Madrid
 
 # This file is part of Wirecloud.
 
@@ -17,9 +17,8 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with Wirecloud.  If not, see <http://www.gnu.org/licenses/>.
 
-
 import codecs
-import Cookie
+from six.moves.http_cookies import SimpleCookie
 from io import BytesIO
 import mimetypes
 import os
@@ -28,23 +27,26 @@ import shutil
 import stat
 import sys
 from tempfile import mkdtemp
-from urllib2 import URLError, HTTPError
-from urlparse import urlparse
+from six.moves.urllib.error import URLError, HTTPError
+from six.moves.urllib.parse import unquote, urlparse
 
-from django.contrib.auth.models import User
+from django.contrib.auth.models import Group, User
 from django.contrib.staticfiles import finders
+from django.core import management
 from django.test import LiveServerTestCase
 from django.test import TransactionTestCase
 from django.test.client import Client
 from django.utils import translation
-from django.utils.importlib import import_module
+import mock
+from six import text_type
 
-from wirecloud.platform.localcatalogue.utils import install_resource
+from wirecloud.platform.localcatalogue.utils import fix_dev_version, install_resource
 from wirecloud.platform.widget import utils as showcase
-from wirecloud.proxy.views import WIRECLOUD_PROXY
+from wirecloud.platform.workspace.utils import create_workspace
 from wirecloud.catalogue import utils as catalogue
-from wirecloud.commons.utils import downloader
-from wirecloud.commons.utils.remote import MobileWirecloudRemoteTestCase, WirecloudRemoteTestCase
+from wirecloud.commons.searchers import get_available_search_engines
+from wirecloud.commons.utils.http import REASON_PHRASES
+from wirecloud.commons.utils.remote import WirecloudRemoteTestCase, FieldTester
 from wirecloud.commons.utils.wgt import WgtDeployer, WgtFile
 
 
@@ -99,6 +101,27 @@ def restoretree(backup_path, dest_path):
             shutil.copy2(srcname, dstname)
 
 
+class RealWebServer(object):
+
+    def __init__(self):
+        self._request_method = requests.request
+
+    def request(self, method, url, *args, **kwargs):
+        response = self._request_method(method, url, *args, **kwargs)
+
+        if 'Content-Encoding' in response.headers:
+            # We have decode the body
+            del response.headers['Content-Encoding']
+            response.headers['Content-Length'] = len(response.content)
+
+        return {
+            'status_code': response.status_code,
+            'headers': response.headers,
+            'content': response.content,
+            'cookies': response.cookies
+        }
+
+
 class DynamicWebServer(object):
 
     responses = {}
@@ -119,6 +142,9 @@ class DynamicWebServer(object):
 
     def request(self, method, url, *args, **kwargs):
 
+        if 'data' not in kwargs or kwargs['data'] is None:
+            kwargs['data'] = BytesIO(b'')
+
         parsed_url = urlparse(url)
         if parsed_url.path not in self.responses or method not in self.responses[parsed_url.path]:
 
@@ -175,7 +201,7 @@ class LocalFileSystemServer(object):
             raise HTTPError('url', '405', 'Method not allowed', None, None)
 
         parsed_url = urlparse(url)
-        final_path = os.path.normpath(os.path.join(self.base_path, parsed_url.path[1:]))
+        final_path = os.path.normpath(os.path.join(self.base_path, unquote(parsed_url.path[1:])))
         if final_path.startswith(self.base_path) and os.path.isfile(final_path):
             f = codecs.open(final_path, 'rb')
             contents = f.read()
@@ -196,14 +222,10 @@ class StreamContent(object):
 
     def __init__(self, content):
 
-        if not hasattr(content, '__iter__'):
-            self._content = BytesIO(content)
-        else:
-            self._content = content
+        if isinstance(content, text_type):
+            content = content.encode('utf8')
 
-    def read(self, *args, **kwargs):
-
-        return self._content.read(*args, **kwargs)
+        self._content = BytesIO(content)
 
     def stream(self, *args, **kwargs):
 
@@ -223,9 +245,6 @@ class FakeNetwork(object):
     def __call__(self, method, url, *args, **kwargs):
         parsed_url = urlparse(url)
 
-        if 'data' not in kwargs or kwargs['data'] is None:
-            kwargs['data'] = BytesIO('')
-
         if parsed_url.scheme not in self._servers or parsed_url.netloc not in self._servers[parsed_url.scheme]:
             raise URLError('not valid')
 
@@ -237,27 +256,29 @@ class FakeNetwork(object):
         res = requests.Response()
         res.url = res_info.get('url', url)
         res.status_code = res_info.get('status_code', 200)
+        res.reason_phrase = res_info.get('reason_phrase', REASON_PHRASES.get(res.status_code, 'UNKNOWN STATUS CODE'))
+
         if 'reason' in res_info:
             res.reason = res_info['reason']
 
         if 'headers' in res_info:
             res.headers.update(res_info['headers'])
 
-            if 'Set-Cookie' in res_info['headers']:
-                cookies = Cookie.SimpleCookie()
+            if 'Set-Cookie' in res_info['headers'] and 'cookies' not in res_info:
+                cookies = SimpleCookie()
                 for entry in res_info['headers']['Set-Cookie'].split(','):
-                    cookies.load(entry)
+                    cookies.load(str(entry))
                 res.cookies.update(cookies)
 
+        if 'cookies' in res_info:
+            res.cookies.update(res_info['cookies'])
+
         res.raw = StreamContent(res_info.get('content', ''))
 
         return res
 
     def mock_requests(self):
 
-        if self.old_requests_request is not None:
-            return
-
         def request_mock(method, url, *args, **kwargs):
             res_info = self(method.upper(), url, *args, **kwargs)
             return self._prepare_response(res_info, url)
@@ -270,24 +291,60 @@ class FakeNetwork(object):
             res_info = self('POST', url, *args, **kwargs)
             return self._prepare_response(res_info, url)
 
-        self.old_requests_request = requests.request
-        requests.request = request_mock
-        self.old_requests_get = requests.get
-        requests.get = get_mock
-        self.old_requests_post = requests.post
-        requests.post = post_mock
+        self.patcher = mock.patch.multiple('requests', get=get_mock, post=post_mock, request=request_mock)
+        self.patcher.start()
 
     def unmock_requests(self):
-        requests.request = self.old_requests_request
-        requests.get = self.old_requests_get
-        requests.post = self.old_requests_post
-        self.old_requests_request = None
-        self.old_requests_get = None
-        self.old_requests_post = None
+        self.patcher.stop()
+
+
+def prepare_temporal_resource_directories(cls):
+
+    from django.conf import settings
+
+    cls.tmp_dir = mkdtemp()
+
+    # Whoosh indexes
+    cls.old_index_dir = settings.WIRECLOUD_INDEX_DIR
+    settings.WIRECLOUD_INDEX_DIR = os.path.join(cls.tmp_dir, 'whoosh_indexes')
+
+    # catalogue deployer
+    cls.old_catalogue_deployer = catalogue.wgt_deployer
+    cls.catalogue_tmp_dir_backup = os.path.join(cls.tmp_dir, 'catalogue_backup')
+    cls.catalogue_tmp_dir = os.path.join(cls.tmp_dir, 'catalogue')
+    catalogue.wgt_deployer = WgtDeployer(cls.catalogue_tmp_dir)
+
+    # showcase deployer
+    cls.old_deployer = showcase.wgt_deployer
+    cls.localcatalogue_tmp_dir_backup = os.path.join(cls.tmp_dir, 'localcatalogue_backup')
+    cls.localcatalogue_tmp_dir = os.path.join(cls.tmp_dir, 'localcatalogue')
+    showcase.wgt_deployer = WgtDeployer(cls.localcatalogue_tmp_dir)
+
+    # deploy resource files
+    for resource_file in cls.base_resources:
+        resource_file = open(os.path.join(cls.shared_test_data_dir, resource_file), 'rb')
+        resource_wgt = WgtFile(resource_file)
+        catalogue.add_packaged_resource(resource_file, None, wgt_file=resource_wgt, deploy_only=True)
+        showcase.wgt_deployer.deploy(resource_wgt)
+        resource_file.close()
+
+    # And freeze the resource files backup directories
+    if os.path.exists(cls.localcatalogue_tmp_dir):
+        os.rename(cls.localcatalogue_tmp_dir, cls.localcatalogue_tmp_dir_backup)
+    else:
+        os.mkdir(cls.localcatalogue_tmp_dir_backup)
+
+    if os.path.exists(cls.catalogue_tmp_dir):
+        os.rename(cls.catalogue_tmp_dir, cls.catalogue_tmp_dir_backup)
+    else:
+        os.mkdir(cls.catalogue_tmp_dir_backup)
 
 
 class WirecloudTestCase(TransactionTestCase):
 
+    base_resources = ()
+    populate = True
+
     @classmethod
     def setUpClass(cls):
 
@@ -313,33 +370,19 @@ class WirecloudTestCase(TransactionTestCase):
         }))
         cls.network.mock_requests()
 
-        # catalogue deployer
-        cls.old_catalogue_deployer = catalogue.wgt_deployer
-        cls.catalogue_tmp_dir_backup = mkdtemp()
-        cls.catalogue_tmp_dir = mkdtemp()
-        catalogue.wgt_deployer = WgtDeployer(cls.catalogue_tmp_dir)
-
-        # showcase deployer
-        cls.old_deployer = showcase.wgt_deployer
-        cls.localcatalogue_tmp_dir_backup = mkdtemp()
-        cls.tmp_dir = mkdtemp()
-        showcase.wgt_deployer = WgtDeployer(cls.tmp_dir)
-
-        restoretree(cls.tmp_dir, cls.localcatalogue_tmp_dir_backup)
-        restoretree(cls.catalogue_tmp_dir, cls.catalogue_tmp_dir_backup)
+        prepare_temporal_resource_directories(cls)
 
         super(WirecloudTestCase, cls).setUpClass()
 
     @classmethod
     def tearDownClass(cls):
 
+        # Remove temporal directory
+        shutil.rmtree(cls.tmp_dir, ignore_errors=True)
+
         # deployers
         catalogue.wgt_deployer = cls.old_catalogue_deployer
-        shutil.rmtree(cls.catalogue_tmp_dir_backup, ignore_errors=True)
-        shutil.rmtree(cls.catalogue_tmp_dir, ignore_errors=True)
         showcase.wgt_deployer = cls.old_deployer
-        shutil.rmtree(cls.localcatalogue_tmp_dir_backup, ignore_errors=True)
-        shutil.rmtree(cls.tmp_dir, ignore_errors=True)
 
         # Restore previous language configuration
         from django.conf import settings
@@ -348,6 +391,9 @@ class WirecloudTestCase(TransactionTestCase):
         settings.LANGUAGE_CODE = cls.old_LANGUAGE_CODE
         settings.DEFAULT_LANGUAGE = cls.old_DEFAULT_LANGUAGE
 
+        # Restore old index dir
+        settings.WIRECLOUD_INDEX_DIR = cls.old_index_dir
+
         # Clear cache
         from django.core.cache import cache
         cache.clear()
@@ -360,7 +406,7 @@ class WirecloudTestCase(TransactionTestCase):
     def setUp(self):
 
         # deployers
-        restoretree(self.localcatalogue_tmp_dir_backup, self.tmp_dir)
+        restoretree(self.localcatalogue_tmp_dir_backup, self.localcatalogue_tmp_dir)
         restoretree(self.catalogue_tmp_dir_backup, self.catalogue_tmp_dir)
 
         # clean example.com responses
@@ -376,6 +422,18 @@ class WirecloudTestCase(TransactionTestCase):
         # Restore English as the default language
         self.changeLanguage('en')
 
+        # Populate initial db
+        if self.populate:
+            management.call_command('populate', verbosity=0, interactive=False)
+
+    def tearDown(self):
+
+        from django.conf import settings
+
+        for searcher in get_available_search_engines():
+            searcher.clear_cache()
+        shutil.rmtree(settings.WIRECLOUD_INDEX_DIR, ignore_errors=True)
+
     def changeLanguage(self, new_language):
 
         from django.conf import settings
@@ -385,7 +443,7 @@ class WirecloudTestCase(TransactionTestCase):
         translation.activate(new_language)
 
 
-def uses_extra_resources(resources, shared=False, public=True, users=(), groups=()):
+def uses_extra_resources(resources, shared=False, public=True, users=(), groups=(), deploy_only=False, creator=None):
 
     def wrap(test_func):
 
@@ -396,27 +454,59 @@ def uses_extra_resources(resources, shared=False, public=True, users=(), groups=
             else:
                 base = self.test_data_dir
 
+            final_creator = User.objects.get(username=creator) if creator is not None else None
+
+            final_users = tuple(User.objects.get(username=user) for user in users)
+            final_groups = tuple(Group.objects.get(name=group) for group in groups)
+
             for resource in resources:
                 wgt_file = open(os.path.join(base, resource), 'rb')
                 wgt = WgtFile(wgt_file)
 
-                resource = install_resource(wgt, None, None, True)
+                fix_dev_version(wgt, final_creator)
+                if deploy_only:
+                    catalogue.add_packaged_resource(wgt.get_underlying_file(), final_creator, wgt_file=wgt, deploy_only=True)
+                    wgt_file.close()
+                    continue
+
+                resource = install_resource(wgt, final_creator)
 
                 if public:
                     resource.public = True
                     resource.save()
 
-                final_users = (User.objects.get(username=user) for user in users)
                 resource.users.add(*final_users)
-
-                final_groups = (Group.objects.get(name=group) for group in groups)
                 resource.groups.add(*final_groups)
 
                 wgt_file.close()
 
             return test_func(self, *args, **kwargs)
 
-        wrapper.func_name = test_func.func_name
+        wrapper.__name__ = test_func.__name__
+        return wrapper
+
+    return wrap
+
+
+def uses_extra_workspace(owner, file_name, shared=False, public=False, users=(), groups=()):
+
+    def wrap(test_func):
+
+        def wrapper(self, *args, **kwargs):
+
+            owner_user = User.objects.get(username=owner)
+
+            if shared:
+                base = self.shared_test_data_dir
+            else:
+                base = self.test_data_dir
+
+            with open(os.path.join(base, file_name), 'rb') as f:
+                create_workspace(owner_user, f)
+
+            return test_func(self, *args, **kwargs)
+
+        wrapper.__name__ = test_func.__name__
         return wrapper
 
     return wrap
@@ -424,15 +514,19 @@ def uses_extra_resources(resources, shared=False, public=True, users=(), groups=
 
 class WirecloudSeleniumTestCase(LiveServerTestCase, WirecloudRemoteTestCase):
 
-    fixtures = ('initial_data', 'selenium_test_data')
+    fixtures = ('selenium_test_data',)
+    base_resources = ('Wirecloud_TestOperator_1.0.zip', 'Wirecloud_Test_1.0.wgt', 'Wirecloud_test-mashup_1.0.wgt')
     __test__ = False
 
+    # Only affecting Django 1.11+
+    host = os.environ.get('DJANGO_LIVE_TEST_SERVER_HOST', 'localhost')
+
     @classmethod
     def setUpClass(cls):
 
         from django.conf import settings
 
-        WirecloudRemoteTestCase.setUpClass.im_func(cls)
+        WirecloudRemoteTestCase.setUpClass.__func__(cls)
 
         cls.old_LANGUAGES = settings.LANGUAGES
         cls.old_LANGUAGE_CODE = settings.LANGUAGE_CODE
@@ -451,35 +545,14 @@ class WirecloudSeleniumTestCase(LiveServerTestCase, WirecloudRemoteTestCase):
         }))
         cls.network.mock_requests()
 
-        # catalogue deployer
-        cls.old_catalogue_deployer = catalogue.wgt_deployer
-        cls.catalogue_tmp_dir_backup = mkdtemp()
-        cls.catalogue_tmp_dir = mkdtemp()
-        catalogue.wgt_deployer = WgtDeployer(cls.catalogue_tmp_dir)
+        prepare_temporal_resource_directories(cls)
 
-        # showcase deployer
-        cls.old_deployer = showcase.wgt_deployer
-        cls.localcatalogue_tmp_dir_backup = mkdtemp()
-        cls.tmp_dir = mkdtemp()
-        showcase.wgt_deployer = WgtDeployer(cls.tmp_dir)
+        # Browsers doesn't use content negotiation using ETags with HTTP 1.0 servers
+        # Force Django to use HTTP 1.1 when using the runserver command
+        from wsgiref import simple_server
+        simple_server.ServerHandler.http_version = "1.1"
 
-        # deploy resource files
-        operator_wgt_file = open(os.path.join(cls.shared_test_data_dir, 'Wirecloud_TestOperator_1.0.zip'), 'rb')
-        operator_wgt = WgtFile(operator_wgt_file)
-        catalogue.add_widget_from_wgt(operator_wgt_file, None, wgt_file=operator_wgt, deploy_only=True)
-        showcase.wgt_deployer.deploy(operator_wgt)
-        operator_wgt_file.close()
-
-        widget_wgt_file = open(os.path.join(cls.shared_test_data_dir, 'Wirecloud_Test_1.0.wgt'))
-        widget_wgt = WgtFile(widget_wgt_file)
-        catalogue.add_widget_from_wgt(widget_wgt_file, None, wgt_file=widget_wgt, deploy_only=True)
-        showcase.wgt_deployer.deploy(widget_wgt)
-        widget_wgt_file.close()
-
-        restoretree(cls.tmp_dir, cls.localcatalogue_tmp_dir_backup)
-        restoretree(cls.catalogue_tmp_dir, cls.catalogue_tmp_dir_backup)
-
-        LiveServerTestCase.setUpClass.im_func(cls)
+        LiveServerTestCase.setUpClass.__func__(cls)
 
         cls.network._servers['http'][cls.server_thread.host + ':' + str(cls.server_thread.port)] = LiveServer()
 
@@ -488,18 +561,20 @@ class WirecloudSeleniumTestCase(LiveServerTestCase, WirecloudRemoteTestCase):
 
         from django.conf import settings
 
-        WirecloudRemoteTestCase.tearDownClass.im_func(cls)
+        WirecloudRemoteTestCase.tearDownClass.__func__(cls)
 
         # Unmock network requests
         cls.network.unmock_requests()
 
+        # Remove temporal directory
+        shutil.rmtree(cls.tmp_dir, ignore_errors=True)
+
         # deployers
         catalogue.wgt_deployer = cls.old_catalogue_deployer
-        shutil.rmtree(cls.catalogue_tmp_dir_backup, ignore_errors=True)
-        shutil.rmtree(cls.catalogue_tmp_dir, ignore_errors=True)
         showcase.wgt_deployer = cls.old_deployer
-        shutil.rmtree(cls.localcatalogue_tmp_dir_backup, ignore_errors=True)
-        shutil.rmtree(cls.tmp_dir, ignore_errors=True)
+
+        # Restore old index dir
+        settings.WIRECLOUD_INDEX_DIR = cls.old_index_dir
 
         settings.LANGUAGES = cls.old_LANGUAGES
         settings.LANGUAGE_CODE = cls.old_LANGUAGE_CODE
@@ -511,7 +586,7 @@ class WirecloudSeleniumTestCase(LiveServerTestCase, WirecloudRemoteTestCase):
 
         from django.core.cache import cache
 
-        restoretree(self.localcatalogue_tmp_dir_backup, self.tmp_dir)
+        restoretree(self.localcatalogue_tmp_dir_backup, self.localcatalogue_tmp_dir)
         restoretree(self.catalogue_tmp_dir_backup, self.catalogue_tmp_dir)
         cache.clear()
         try:
@@ -519,116 +594,32 @@ class WirecloudSeleniumTestCase(LiveServerTestCase, WirecloudRemoteTestCase):
         except:
             pass
 
-        super(WirecloudSeleniumTestCase, self).setUp()
+        LiveServerTestCase.setUp(self)
+        WirecloudRemoteTestCase.setUp(self)
+        management.call_command('populate', verbosity=0, interactive=False)
 
-
-class MobileWirecloudSeleniumTestCase(LiveServerTestCase, MobileWirecloudRemoteTestCase):
-
-    fixtures = ('initial_data', 'selenium_test_data')
-    __test__ = False
-
-    @classmethod
-    def setUpClass(cls):
+    def tearDown(self):
 
         from django.conf import settings
 
-        MobileWirecloudRemoteTestCase.setUpClass.im_func(cls)
+        for searcher in get_available_search_engines():
+            searcher.clear_cache()
+        shutil.rmtree(settings.WIRECLOUD_INDEX_DIR, ignore_errors=True)
 
-        cls.old_LANGUAGES = settings.LANGUAGES
-        cls.old_LANGUAGE_CODE = settings.LANGUAGE_CODE
-        cls.old_DEFAULT_LANGUAGE = settings.DEFAULT_LANGUAGE
-        settings.LANGUAGES = (('en', 'English'),)
-        settings.LANGUAGE_CODE = 'en'
-        settings.DEFAULT_LANGUAGE = 'en'
+        LiveServerTestCase.tearDown(self)
+        WirecloudRemoteTestCase.tearDown(self)
 
-        # Mock network requests
-        cls.network = FakeNetwork(getattr(cls, 'servers', {
-            'http': {
-                'localhost:8001': LocalFileSystemServer(os.path.join(os.path.dirname(__file__), '..', 'test-data', 'src')),
-                'macs.example.com': LocalFileSystemServer(os.path.join(os.path.dirname(__file__), '..', 'test-data')),
-                'example.com': DynamicWebServer(),
-            },
-        }))
-        cls.network.mock_requests()
-
-        # catalogue deployer
-        cls.old_catalogue_deployer = catalogue.wgt_deployer
-        cls.catalogue_tmp_dir_backup = mkdtemp()
-        cls.catalogue_tmp_dir = mkdtemp()
-        catalogue.wgt_deployer = WgtDeployer(cls.catalogue_tmp_dir)
-
-        # showcase deployer
-        cls.old_deployer = showcase.wgt_deployer
-        cls.localcatalogue_tmp_dir_backup = mkdtemp()
-        cls.tmp_dir = mkdtemp()
-        showcase.wgt_deployer = WgtDeployer(cls.tmp_dir)
-
-        # deploy resource files
-        operator_wgt_file = open(os.path.join(cls.shared_test_data_dir, 'Wirecloud_TestOperator_1.0.zip'), 'rb')
-        operator_wgt = WgtFile(operator_wgt_file)
-        catalogue.add_widget_from_wgt(operator_wgt_file, None, wgt_file=operator_wgt, deploy_only=True)
-        showcase.wgt_deployer.deploy(operator_wgt)
-        operator_wgt_file.close()
-
-        widget_wgt_file = open(os.path.join(cls.shared_test_data_dir, 'Wirecloud_Test_1.0.wgt'))
-        widget_wgt = WgtFile(widget_wgt_file)
-        catalogue.add_widget_from_wgt(widget_wgt_file, None, wgt_file=widget_wgt, deploy_only=True)
-        showcase.wgt_deployer.deploy(widget_wgt)
-        widget_wgt_file.close()
-
-        restoretree(cls.tmp_dir, cls.localcatalogue_tmp_dir_backup)
-        restoretree(cls.catalogue_tmp_dir, cls.catalogue_tmp_dir_backup)
-
-        LiveServerTestCase.setUpClass.im_func(cls)
-
-        cls.network._servers['http'][cls.server_thread.host + ':' + str(cls.server_thread.port)] = LiveServer()
-
-    @classmethod
-    def tearDownClass(cls):
-
-        from django.conf import settings
-
-        MobileWirecloudRemoteTestCase.tearDownClass.im_func(cls)
-
-        # Unmock network requests
-        cls.network.unmock_requests()
-
-        # deployers
-        catalogue.wgt_deployer = cls.old_catalogue_deployer
-        shutil.rmtree(cls.catalogue_tmp_dir_backup, ignore_errors=True)
-        shutil.rmtree(cls.catalogue_tmp_dir, ignore_errors=True)
-        showcase.wgt_deployer = cls.old_deployer
-        shutil.rmtree(cls.localcatalogue_tmp_dir_backup, ignore_errors=True)
-        shutil.rmtree(cls.tmp_dir, ignore_errors=True)
-
-        settings.LANGUAGES = cls.old_LANGUAGES
-        settings.LANGUAGE_CODE = cls.old_LANGUAGE_CODE
-        settings.DEFAULT_LANGUAGE = cls.old_DEFAULT_LANGUAGE
-
-        super(MobileWirecloudSeleniumTestCase, cls).tearDownClass()
-
-    def setUp(self):
-
-        from django.core.cache import cache
-
-        restoretree(self.localcatalogue_tmp_dir_backup, self.tmp_dir)
-        restoretree(self.catalogue_tmp_dir_backup, self.catalogue_tmp_dir)
-        cache.clear()
-        try:
-            self.network._servers['http']['example.com'].clear()
-        except:
-            pass
-
-        super(MobileWirecloudSeleniumTestCase, self).setUp()
+    def send_basic_event(self, widget, event="hello world!!"):
+        with widget:
+            field = FieldTester(self, self.driver.find_element_by_css_selector("#send input"))
+            field.set_value(event)
+            self.driver.find_element_by_css_selector("#send button").click()
 
 
 DEFAULT_BROWSER_CONF = {
     'Firefox': {
         'CLASS': 'selenium.webdriver.Firefox',
     },
-    'GoogleChrome': {
-        'CLASS': 'selenium.webdriver.Chrome',
-    },
 }
 
 
@@ -636,49 +627,36 @@ def get_configured_browsers():
 
     from django.conf import settings
 
-    return getattr(settings, 'WIRECLOUD_SELENIUM_BROWSER_COMMANDS', DEFAULT_BROWSER_CONF)
+    return getattr(settings, 'WIRECLOUD_SELENIUM_TEST_BROWSERS', DEFAULT_BROWSER_CONF)
 
-def wirecloud_selenium_test_case(classes, namespace=None, browsers=None):
+
+def wirecloud_selenium_test_case(klass_instance, browsers=None):
 
     if browsers is None:
         browsers = get_configured_browsers()
 
-    try:
-        iter(classes)
-    except TypeError:
-        classes = (classes,)
+    for browser_name in browsers:
+        browser = browsers[browser_name]
+        tests_class_name = browser_name + klass_instance.__name__
 
-    for class_name in classes:
-        for browser_name in browsers:
-            browser = browsers[browser_name]
+        new_klass = type(
+            tests_class_name,
+            (klass_instance,),
+            {
+                '__test__': True,
+                '_webdriver_class': browser['CLASS'],
+                '_webdriver_args': browser.get('ARGS', None),
+            }
+        )
 
-            if isinstance(class_name, basestring):
-                module_name, klass_name = class_name.rsplit('.', 1)
-                tests_class_name = browser_name + klass_name
-                module = import_module(module_name)
-                klass_instance = getattr(module, klass_name)
-            else:
-                tests_class_name = browser_name + class_name.__name__
-                klass_instance = class_name
+        klass_namespace = sys.modules[klass_instance.__module__]
 
-            new_klass = type(
-                tests_class_name,
-                (klass_instance,),
-                {
-                    '__test__': True,
-                    '_webdriver_class': browser['CLASS'],
-                    '_webdriver_args': browser.get('ARGS', None),
-                }
-            )
+        try:
+            setattr(klass_namespace, tests_class_name, new_klass)
+        except AttributeError:
+            klass_namespace[tests_class_name] = new_klass
+
+    return klass_instance
 
-            if namespace is not None:
-                klass_namespace = namespace
-            else:
-                klass_namespace = sys.modules[klass_instance.__module__]
 
-            try:
-                setattr(klass_namespace, tests_class_name, new_klass)
-            except AttributeError:
-                klass_namespace[tests_class_name] = new_klass
 wirecloud_selenium_test_case.__test__ = False
-build_selenium_test_cases = wirecloud_selenium_test_case
