@@ -1,5 +1,5 @@
 /*
- *     (C) Copyright 2008-2013 Universidad Politécnica de Madrid
+ *     Copyright 2008-2016 (c) CoNWeT Lab., Universidad Politécnica de Madrid
  *
  *     This file is part of Wirecloud Platform.
  *
@@ -19,35 +19,56 @@
  *
  */
 
-/*global Wirecloud*/
+/* globals Wirecloud */
 
-(function () {
+
+(function (utils) {
 
     "use strict";
 
-    var TargetEndpoint = function TargetEndpoint(name, type, friendCode, id) {
-        Wirecloud.wiring.Endpoint.call(this, name, type, friendCode, id);
+    var TargetEndpoint = function TargetEndpoint() {
+        Wirecloud.wiring.Endpoint.call(this);
         this.inputs = [];
+        this.connections = [];
+    };
+    utils.inherit(TargetEndpoint, Wirecloud.wiring.Endpoint);
+
+    TargetEndpoint.prototype.connect = function connect(input, connection) {
+        if (!(input instanceof Wirecloud.wiring.SourceEndpoint)) {
+            throw new TypeError('Invalid source endpoint');
+        }
+
+        input.connect(this, connection);
     };
 
-    TargetEndpoint.prototype = new Wirecloud.wiring.Endpoint();
+    TargetEndpoint.prototype.disconnect = function disconnect(input) {
+        if (!(input instanceof Wirecloud.wiring.SourceEndpoint)) {
+            throw new TypeError('Invalid source endpoint');
+        }
+
+        input.disconnect(this);
+    };
+
+    TargetEndpoint.prototype.propagate = function propagate(data, options) {
+        // Do nothing by default
+    };
 
     /**
      * @private
      */
-    TargetEndpoint.prototype._addInput = function _addInput(input) {
+    TargetEndpoint.prototype._addInput = function _addInput(input, connection) {
         this.inputs.push(input);
+        this.connections.push(connection);
     };
 
     /**
      * @private
      */
-    TargetEndpoint.prototype._removeInput = function _removeInput(input) {
+    TargetEndpoint.prototype._removeInput = function _removeInput(input, connection) {
         var index = this.inputs.indexOf(input);
 
-        if (index != -1) {
-            this.inputs.splice(index, input);
-        }
+        this.inputs.splice(index, 1);
+        this.connections.splice(index, 1);
     };
 
     TargetEndpoint.prototype.fullDisconnect = function fullDisconnect() {
@@ -60,4 +81,4 @@
 
     Wirecloud.wiring.TargetEndpoint = TargetEndpoint;
 
-})();
+})(Wirecloud.Utils);
