@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2012-2014 (c) CoNWeT Lab., Universidad Politécnica de Madrid
+# Copyright (c) 2012-2017 CoNWeT Lab., Universidad Politécnica de Madrid
 
 # This file is part of Wirecloud.
 
@@ -17,8 +17,10 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with Wirecloud.  If not, see <http://www.gnu.org/licenses/>.
 
+from __future__ import unicode_literals
+
+from io import BytesIO
 import json
-from cStringIO import StringIO
 import os
 import zipfile
 
@@ -26,41 +28,37 @@ from django.db import IntegrityError
 from django.http import HttpResponse
 from django.shortcuts import get_object_or_404
 from django.utils.translation import ugettext as _
+from six import string_types
 
 from wirecloud.catalogue import utils as catalogue
 from wirecloud.catalogue.models import CatalogueResource
 from wirecloud.commons.baseviews import Resource, Service
-from wirecloud.commons.utils.cache import no_cache
 from wirecloud.commons.utils.db import save_alternative
-from wirecloud.commons.utils.downloader import download_http_content
-from wirecloud.commons.utils.http import authentication_required, authentication_required_cond, build_error_response, get_content_type, supported_request_mime_types, supported_response_mime_types
+from wirecloud.commons.utils.http import authentication_required, authentication_required_cond, build_error_response, get_content_type, normalize_boolean_param, consumes, parse_json_request, produces
 from wirecloud.commons.utils.template import is_valid_name, is_valid_vendor, is_valid_version, TemplateParser
 from wirecloud.commons.utils.transaction import commit_on_http_success
+from wirecloud.commons.utils.urlify import URLify
 from wirecloud.commons.utils.wgt import WgtFile
-from wirecloud.platform.get_data import get_workspace_data, get_global_workspace_data
-from wirecloud.platform.models import IWidget, Tab, UserWorkspace, Workspace
+from wirecloud.platform.models import Tab, UserWorkspace, Workspace
+from wirecloud.platform.preferences.views import update_workspace_preferences
 from wirecloud.platform.settings import ALLOW_ANONYMOUS_ACCESS
-from wirecloud.platform.workspace.mashupTemplateGenerator import build_json_template_from_workspace, build_rdf_template_from_workspace
+from wirecloud.platform.wiring.utils import get_wiring_skeleton
+from wirecloud.platform.workspace.mashupTemplateGenerator import build_json_template_from_workspace, build_xml_template_from_workspace
 from wirecloud.platform.workspace.mashupTemplateParser import check_mashup_dependencies, buildWorkspaceFromTemplate, fillWorkspaceUsingTemplate, MissingDependencies
-from wirecloud.platform.workspace.utils import deleteTab, createTab, get_workspace_list, setVisibleTab, set_variable_value
-from wirecloud.platform.markets.utils import get_market_managers
+from wirecloud.platform.workspace.utils import deleteTab, createTab, get_tab_data, get_workspace_list, get_workspace_data, get_global_workspace_data, setVisibleTab, delete_workspace
+from wirecloud.platform.markets.utils import get_local_catalogue
 
 
-def createEmptyWorkspace(workspaceName, user, allow_renaming=False):
-    active = False
-    workspaces = UserWorkspace.objects.filter(user__id=user.id, active=True)
-    if workspaces.count() == 0:
-        # there isn't yet an active workspace
-        active = True
+def createEmptyWorkspace(title, user, allow_renaming=False, name=None):
+    if name is None or name == '':
+        name = URLify(title)
 
-    empty_wiring = '{"operators": {}, "connections": []}'
-
-    workspace = Workspace(name=workspaceName, creator=user, wiringStatus=empty_wiring)
+    workspace = Workspace(title=title, name=name, creator=user, wiringStatus=get_wiring_skeleton())
     if allow_renaming is True:
         save_alternative(Workspace, 'name', workspace)
     else:
         workspace.save()
-    UserWorkspace.objects.create(user=user, workspace=workspace, active=active)
+    UserWorkspace.objects.create(user=user, workspace=workspace)
 
     # Tab creation
     createTab(_('Tab'), workspace)
@@ -68,73 +66,51 @@ def createEmptyWorkspace(workspaceName, user, allow_renaming=False):
     return workspace
 
 
-def setActiveWorkspace(user, workspace):
-
-    UserWorkspace.objects.filter(user=user, active=True).exclude(workspace=workspace).update(active=False)
-    UserWorkspace.objects.filter(user=user, workspace=workspace).update(active=True)
-
-
-def normalize_boolean_param(name, value):
-
-    if isinstance(value, basestring):
-        value = value.strip().lower()
-        if value not in ('true', 'false'):
-            raise ValueError(_('Invalid %(parameter)s value') % name)
-        return value == 'true'
-    elif not isinstance(value, bool):
-        return TypeError(_('Invalid %(parameter) type') % name)
-
-    return value
-
-
 class WorkspaceCollection(Resource):
 
-    @supported_response_mime_types(('application/json',))
+    @produces(('application/json',))
     @commit_on_http_success
-    @no_cache
     def read(self, request):
 
-        workspaces, _junk = get_workspace_list(request.user)
+        workspaces = get_workspace_list(request.user)
         data_list = [get_workspace_data(workspace, request.user) for workspace in workspaces]
 
-        return HttpResponse(json.dumps(data_list), content_type='application/json; charset=UTF-8')
+        return HttpResponse(json.dumps(data_list, sort_keys=True), content_type='application/json; charset=UTF-8')
 
     @authentication_required
-    @supported_request_mime_types(('application/json',))
-    @supported_response_mime_types(('application/json',))
+    @consumes(('application/json',))
+    @produces(('application/json',))
     @commit_on_http_success
     def create(self, request):
 
-        try:
-            data = json.loads(request.body)
-        except ValueError as e:
-            msg = _("malformed json data: %s") % unicode(e)
-            return build_error_response(request, 400, msg)
+        data = parse_json_request(request)
 
         workspace_name = data.get('name', '').strip()
+        workspace_title = data.get('title', '').strip()
         workspace_id = data.get('workspace', '')
         mashup_id = data.get('mashup', '')
-        try:
-            allow_renaming = normalize_boolean_param('allow_renaming', data.get('allow_renaming', False))
-            dry_run = normalize_boolean_param('allow_renaming', data.get('dry_run', False))
-        except (TypeError, ValueError) as e:
-            return build_error_response(request, 422, unicode(e))
+        initial_pref_values = data.get('preferences', {})
+        allow_renaming = normalize_boolean_param(request, 'allow_renaming', data.get('allow_renaming', False))
+        dry_run = normalize_boolean_param(request, 'dry_run', data.get('dry_run', False))
 
-        if mashup_id == '' and workspace_id == '' and workspace_name == '':
-            return build_error_response(request, 422, _('Missing name parameter'))
-        elif  mashup_id != '' and workspace_id != '':
+        if mashup_id == '' and workspace_id == '' and (workspace_name == '' and workspace_title == ''):
+            return build_error_response(request, 422, _('Missing name or title parameter'))
+        elif mashup_id != '' and workspace_id != '':
             return build_error_response(request, 422, _('Workspace and mashup parameters cannot be used at the same time'))
 
         if mashup_id == '' and workspace_id == '':
 
-            if not is_valid_name(workspace_name):
+            if workspace_title == '':
+                workspace_title = workspace_name
+
+            if workspace_name != '' and not is_valid_name(workspace_name):
                 return build_error_response(request, 422, _('invalid workspace name'))
 
             if dry_run:
                 return HttpResponse(status=204)
 
             try:
-                workspace = createEmptyWorkspace(workspace_name, request.user, allow_renaming=allow_renaming)
+                workspace = createEmptyWorkspace(workspace_title, request.user, name=workspace_name, allow_renaming=allow_renaming)
             except IntegrityError:
                 msg = _('A workspace with the given name already exists')
                 return build_error_response(request, 409, msg)
@@ -153,16 +129,9 @@ class WorkspaceCollection(Resource):
                 except CatalogueResource.DoesNotExist:
                     return build_error_response(request, 422, _('Mashup not found: %(mashup_id)s') % {'mashup_id': mashup_id})
 
-                if resource.fromWGT:
-                    base_dir = catalogue.wgt_deployer.get_base_dir(mashup_vendor, mashup_name, mashup_version)
-                    wgt_file = WgtFile(os.path.join(base_dir, resource.template_uri))
-                    template = TemplateParser(wgt_file.get_template())
-                else:
-                    template = download_http_content(resource.template_uri, user=request.user)
-                    try:
-                        template = TemplateParser(template)
-                    except:
-                        build_error_response(request, 422, _('Downloaded invalid resource description from: %(url)s') % {'url': resource.template_uri})
+                base_dir = catalogue.wgt_deployer.get_base_dir(mashup_vendor, mashup_name, mashup_version)
+                wgt_file = WgtFile(os.path.join(base_dir, resource.template_uri))
+                template = TemplateParser(wgt_file.get_template())
 
             else:
 
@@ -174,7 +143,7 @@ class WorkspaceCollection(Resource):
                     'vendor': 'api',
                     'name': from_ws.name,
                     'version': '1.0',
-                    'title': '',
+                    'title': from_ws.title if from_ws.title is not None and from_ws.title.strip() != "" else from_ws.name,
                     'description': 'Temporal mashup for the workspace copy operation',
                     'email': 'a@example.com',
                 }
@@ -187,20 +156,20 @@ class WorkspaceCollection(Resource):
                 details = {
                     'missingDependencies': e.missing_dependencies,
                 }
-                return build_error_response(request, 422, unicode(e), details=details)
+                return build_error_response(request, 422, e, details=details)
 
             if dry_run:
                 return HttpResponse(status=204)
 
-            if workspace_name == '':
-                workspace_name = None
-
             try:
-                workspace, _junk = buildWorkspaceFromTemplate(template, request.user, allow_renaming=allow_renaming, new_name=workspace_name)
+                workspace, _junk = buildWorkspaceFromTemplate(template, request.user, allow_renaming=allow_renaming, new_name=workspace_name, new_title=workspace_title)
             except IntegrityError:
                 msg = _('A workspace with the given name already exists')
                 return build_error_response(request, 409, msg)
 
+        if len(initial_pref_values) > 0:
+            update_workspace_preferences(workspace, initial_pref_values, invalidate_cache=False)
+
         workspace_data = get_global_workspace_data(workspace, request.user)
 
         return workspace_data.get_response(status_code=201, cacheable=False)
@@ -209,12 +178,15 @@ class WorkspaceCollection(Resource):
 class WorkspaceEntry(Resource):
 
     @authentication_required_cond(ALLOW_ANONYMOUS_ACCESS)
-    @supported_response_mime_types(('application/json',))
-    def read(self, request, workspace_id):
+    @produces(('application/json',))
+    def read(self, request, workspace_id=None, owner=None, name=None):
 
-        workspace = get_object_or_404(Workspace, pk=workspace_id)
+        if workspace_id is not None:
+            workspace = get_object_or_404(Workspace, pk=workspace_id)
+        else:
+            workspace = get_object_or_404(Workspace, creator__username=owner, name=name)
 
-        if not workspace.public and not (request.user.is_authenticated() and workspace.users.filter(pk=request.user.pk).exists()):
+        if not workspace.is_available_for(request.user):
             return build_error_response(request, 403, _("You don't have permission to access this workspace"))
 
         workspace_data = get_global_workspace_data(workspace, request.user)
@@ -222,38 +194,38 @@ class WorkspaceEntry(Resource):
         return workspace_data.get_response()
 
     @authentication_required
-    @supported_request_mime_types(('application/json',))
+    @consumes(('application/json',))
     @commit_on_http_success
     def create(self, request, workspace_id):
 
-        try:
-            ts = json.loads(request.body)
-        except ValueError as e:
-            msg = _("malformed json data: %s") % unicode(e)
-            return build_error_response(request, 400, msg)
+        ts = parse_json_request(request)
+        fields = []
 
-        workspace = Workspace.objects.get(pk=workspace_id)
+        workspace = get_object_or_404(Workspace, pk=workspace_id)
         if not (request.user.is_superuser or workspace.users.filter(pk=request.user.pk).exists()):
             return build_error_response(request, 403, _('You are not allowed to update this workspace'))
 
-        if 'active' in ts:
-
-            active = ts.get('active', False)
-            if isinstance(active, basestring):
-                active = ts['active'].lower() == 'true'
-
-            if active:
-                # Only one active workspace
-                setActiveWorkspace(request.user, workspace)
-            else:
-                currentUserWorkspace = UserWorkspace.objects.get(workspace=workspace, user=request.user)
-                currentUserWorkspace.active = False
-                currentUserWorkspace.save()
-
         if 'name' in ts:
             workspace.name = ts['name']
+            fields.append('name')
 
-        workspace.save()
+        if 'title' in ts:
+            workspace.title = ts['title']
+            fields.append('title')
+
+        if 'description' in ts:
+            workspace.description = ts['description']
+            fields.append('description')
+
+        if 'longdescription' in ts:
+            workspace.longdescription = ts['longdescription']
+            fields.append('longdescription')
+
+        try:
+            workspace.save(update_fields=fields)
+        except IntegrityError:
+            msg = _('A workspace with the given name already exists')
+            return build_error_response(request, 409, msg)
 
         return HttpResponse(status=204)
 
@@ -262,20 +234,10 @@ class WorkspaceEntry(Resource):
     def delete(self, request, workspace_id):
 
         workspace = get_object_or_404(Workspace, pk=workspace_id)
-        if not workspace.users.filter(pk=request.user.pk).exists():
+        if not (request.user.is_superuser or workspace.creator == request.user):
             return build_error_response(request, 403, _('You are not allowed to delete this workspace'))
 
-        UserWorkspace.objects.filter(user=request.user, workspace=workspace).delete()
-        if workspace.users.count() == 0:
-
-            # Remove the workspace
-            iwidgets = IWidget.objects.filter(tab__workspace=workspace)
-            for iwidget in iwidgets:
-                iwidget.delete()
-            workspace.delete()
-
-            from wirecloud.platform.get_data import _invalidate_cached_variable_values
-            _invalidate_cached_variable_values(workspace)
+        delete_workspace(workspace=workspace)
 
         return HttpResponse(status=204)
 
@@ -283,53 +245,43 @@ class WorkspaceEntry(Resource):
 class TabCollection(Resource):
 
     @authentication_required
-    @supported_request_mime_types(('application/json',))
-    @supported_response_mime_types(('application/json',))
+    @consumes(('application/json',))
+    @produces(('application/json',))
     @commit_on_http_success
     def create(self, request, workspace_id):
 
-        try:
-            data = json.loads(request.body)
-        except ValueError as e:
-            msg = _("malformed json data: %s") % unicode(e)
-            return build_error_response(request, 400, msg)
+        workspace = get_object_or_404(Workspace, pk=workspace_id)
+        data = parse_json_request(request)
 
-        if 'name' not in data:
-            return build_error_response(request, 400, _('Malformed tab JSON: expecting tab name.'))
+        if 'name' not in data and 'title' not in data:
+            return build_error_response(request, 422, _('Malformed tab JSON: expecting tab name or title.'))
 
-        tab_name = data['name']
-        workspace = Workspace.objects.get(pk=workspace_id)
         if not (request.user.is_superuser or workspace.creator == request.user):
             return build_error_response(request, 403, _('You are not allowed to create new tabs for this workspace'))
 
+        tab_title = data.get('title')
+        tab_name = data.get('name')
         try:
-            tab = createTab(tab_name, workspace)
+            tab = createTab(tab_title, workspace, name=tab_name)
         except IntegrityError:
             msg = _('A tab with the given name already exists for the workspace')
             return build_error_response(request, 409, msg)
 
-        # Returning created Ids
-        ids = {'id': tab.id, 'name': tab.name}
-
-        return HttpResponse(json.dumps(ids), status=201, content_type='application/json; charset=UTF-8')
+        return HttpResponse(json.dumps(get_tab_data(tab, user=request.user)), status=201, content_type='application/json; charset=UTF-8')
 
 
 class TabOrderService(Service):
 
     @authentication_required
-    @supported_request_mime_types(('application/json',))
+    @consumes(('application/json',))
     @commit_on_http_success
     def process(self, request, workspace_id):
 
-        workspace = Workspace.objects.get(pk=workspace_id)
+        workspace = get_object_or_404(Workspace, pk=workspace_id)
         if not (request.user.is_superuser or workspace.creator == request.user):
             return build_error_response(request, 403, _('You are not allowed to create new tabs for this workspace'))
 
-        try:
-            order = json.loads(request.body)
-        except ValueError as e:
-            msg = _("malformed json data: %s") % unicode(e)
-            return build_error_response(request, 400, msg)
+        order = parse_json_request(request)
 
         tabs = Tab.objects.filter(id__in=order)
 
@@ -342,10 +294,21 @@ class TabOrderService(Service):
 
 class TabEntry(Resource):
 
-    @authentication_required
-    @supported_request_mime_types(('application/json',))
+    @produces(('application/json',))
     @commit_on_http_success
-    def update(self, request, workspace_id, tab_id):
+    def read(self, request, workspace_id, tab_id):
+
+        tab = get_object_or_404(Tab.objects.select_related('workspace'), workspace__pk=workspace_id, pk=tab_id)
+        if not tab.workspace.is_available_for(request.user):
+            return build_error_response(request, 403, _("You don't have permission to access this workspace"))
+
+        data = json.dumps(get_tab_data(tab, user=request.user), sort_keys=True)
+        return HttpResponse(data, status=200, content_type='application/json; charset=UTF-8')
+
+    @authentication_required
+    @consumes(('application/json',))
+    @commit_on_http_success
+    def create(self, request, workspace_id, tab_id):
 
         tab = get_object_or_404(Tab.objects.select_related('workspace'), workspace__pk=workspace_id, pk=tab_id)
         if tab.workspace.creator != request.user:
@@ -355,15 +318,11 @@ class TabEntry(Resource):
         if user_workspace.manager != '':
             return build_error_response(request, 403, _('You are not allowed to update this workspace'))
 
-        try:
-            data = json.loads(request.body)
-        except ValueError as e:
-            msg = _("malformed json data: %s") % unicode(e)
-            return build_error_response(request, 400, msg)
+        data = parse_json_request(request)
 
         if 'visible' in data:
             visible = data['visible']
-            if isinstance(visible, basestring):
+            if isinstance(visible, string_types):
                 visible = visible.strip().lower()
                 if visible not in ('true', 'false'):
                     return build_error_response(request, 422, _('Invalid visible value'))
@@ -372,7 +331,7 @@ class TabEntry(Resource):
                 return build_error_response(request, 422, _('Invalid visible value'))
 
             if visible:
-                #Only one visible tab
+                # Only one visible tab
                 setVisibleTab(request.user, workspace_id, tab)
             else:
                 tab.visible = False
@@ -380,7 +339,14 @@ class TabEntry(Resource):
         if 'name' in data:
             tab.name = data['name']
 
-        tab.save()
+        if 'title' in data:
+            tab.title = data['title']
+
+        try:
+            tab.save()
+        except IntegrityError:
+            msg = _('A tab with the given name already exists for the workspace')
+            return build_error_response(request, 409, msg)
 
         return HttpResponse(status=204)
 
@@ -419,50 +385,27 @@ class TabEntry(Resource):
         return HttpResponse(status=204)
 
 
-class WorkspaceVariableCollection(Resource):
-
-    @authentication_required
-    @supported_request_mime_types(('application/json',))
-    @commit_on_http_success
-    def create(self, request, workspace_id):
-
-        try:
-            iwidgetVariables = json.loads(request.body)
-        except ValueError as e:
-            msg = _("malformed json data: %s") % unicode(e)
-            return build_error_response(request, 400, msg)
-
-        for igVar in iwidgetVariables:
-            set_variable_value(igVar['id'], igVar['value'])
-
-        return HttpResponse(status=204)
-
-
 class MashupMergeService(Service):
 
     @authentication_required
-    @supported_request_mime_types(('application/json',))
+    @consumes(('application/json',))
     @commit_on_http_success
     def process(self, request, to_ws_id):
 
-        try:
-            data = json.loads(request.body)
-        except ValueError as e:
-            msg = _("malformed json data: %s") % unicode(e)
-            return build_error_response(request, 400, msg)
+        to_ws = get_object_or_404(Workspace, id=to_ws_id)
+        if not request.user.is_superuser and to_ws.creator != request.user:
+            return build_error_response(request, 403, _('You are not allowed to update this workspace'))
+
+        data = parse_json_request(request)
 
         mashup_id = data.get('mashup', '')
         workspace_id = data.get('workspace', '')
 
         if mashup_id == '' and workspace_id == '':
             return build_error_response(request, 422, _('Missing workspace or mashup parameter'))
-        elif  mashup_id != '' and workspace_id != '':
+        elif mashup_id != '' and workspace_id != '':
             return build_error_response(request, 422, _('Workspace and mashup parameters cannot be used at the same time'))
 
-        to_ws = get_object_or_404(Workspace, id=to_ws_id)
-        if not request.user.is_superuser and to_ws.creator != request.user:
-            return build_error_response(request, 403, _('You are not allowed to update this workspace'))
-
         if mashup_id != '':
             values = mashup_id.split('/', 3)
             if len(values) != 3:
@@ -476,16 +419,9 @@ class MashupMergeService(Service):
             except CatalogueResource.DoesNotExist:
                 return build_error_response(request, 422, _('Mashup not found: %(mashup_id)s') % {'mashup_id': mashup_id})
 
-            if resource.fromWGT:
-                base_dir = catalogue.wgt_deployer.get_base_dir(mashup_vendor, mashup_name, mashup_version)
-                wgt_file = WgtFile(os.path.join(base_dir, resource.template_uri))
-                template = TemplateParser(wgt_file.get_template())
-            else:
-                template = download_http_content(resource.template_uri, user=request.user)
-                try:
-                    template = TemplateParser(template)
-                except:
-                    build_error_response(request, 424, _('Downloaded invalid resource description from: %(url)s') % {'url': resource.template_uri})
+            base_dir = catalogue.wgt_deployer.get_base_dir(mashup_vendor, mashup_name, mashup_version)
+            wgt_file = WgtFile(os.path.join(base_dir, resource.template_uri))
+            template = TemplateParser(wgt_file.get_template())
 
         else:
 
@@ -506,11 +442,11 @@ class MashupMergeService(Service):
 
         try:
             check_mashup_dependencies(template, request.user)
-        except MissingDependencies, e:
+        except MissingDependencies as e:
             details = {
                 'missingDependencies': e.missing_dependencies,
             }
-            return build_error_response(request, 422, unicode(e), details=details)
+            return build_error_response(request, 422, e, details=details)
 
         fillWorkspaceUsingTemplate(to_ws, template)
         return HttpResponse(status=204)
@@ -520,7 +456,7 @@ def check_json_fields(json, fields):
     missing_fields = []
 
     for field in fields:
-        if not field in json:
+        if field not in json:
             missing_fields.append(field)
 
     return missing_fields
@@ -529,25 +465,31 @@ def check_json_fields(json, fields):
 class WorkspacePublisherEntry(Resource):
 
     @authentication_required
-    @supported_request_mime_types(('application/json', 'multipart/form-data'))
+    @consumes(('application/json', 'multipart/form-data'))
     @commit_on_http_success
     def create(self, request, workspace_id):
 
+        import wirecloud.catalogue.utils as catalogue_utils
+
         content_type = get_content_type(request)[0]
         image_file = None
+        smartphoneimage_file = None
+        extra_files = []
+
         if content_type == 'application/json':
-            received_json = request.body
+            received_json = request.body.decode('utf-8')
         else:
             received_json = request.POST['json']
             image_file = request.FILES.get('image', None)
+            smartphoneimage_file = request.FILES.get('smartphoneimage', None)
 
         try:
             options = json.loads(received_json)
         except ValueError as e:
-            msg = _("malformed json data: %s") % unicode(e)
+            msg = _("malformed json data: %s") % e
             return build_error_response(request, 400, msg)
 
-        missing_fields = check_json_fields(options, ('name', 'vendor', 'version', 'email'))
+        missing_fields = check_json_fields(options, ('name', 'vendor', 'version'))
         if len(missing_fields) > 0:
             return build_error_response(request, 400, _('Malformed JSON. The following field(s) are missing: %(fields)s.') % {'fields': missing_fields})
 
@@ -562,22 +504,31 @@ class WorkspacePublisherEntry(Resource):
 
         workspace = get_object_or_404(Workspace, id=workspace_id)
         if image_file is not None:
-            image_filename = 'images/catalogue' + os.path.splitext(image_file.name)[1]
-            options['image'] = image_filename
-        description = build_rdf_template_from_workspace(options, workspace, request.user)
+            options['image'] = 'images/catalogue' + os.path.splitext(image_file.name)[1]
+            extra_files.append((options['image'], image_file))
+        if smartphoneimage_file is not None:
+            options['smartphoneimage'] = 'images/smartphone' + os.path.splitext(smartphoneimage_file.name)[1]
+            extra_files.append((options['smartphoneimage'], smartphoneimage_file))
+        if 'longdescription' in options:
+            extra_files.append(('DESCRIPTION.md', BytesIO(options['longdescription'].encode('utf-8'))))
+            options['longdescription'] = 'DESCRIPTION.md'
 
-        f = StringIO()
+        description = build_xml_template_from_workspace(options, workspace, request.user)
+
+        # Build mashup wgt file
+        f = BytesIO()
         zf = zipfile.ZipFile(f, 'w')
-        zf.writestr('config.xml', bytes(description.serialize(format='pretty-xml')))
-        if image_file is not None:
-            zf.writestr(image_filename, image_file.read())
+        zf.writestr('config.xml', description.encode('utf-8'))
+        for filename, extra_file in extra_files:
+            zf.writestr(filename, extra_file.read())
+        for resource_info in options['embedded']:
+            (vendor, name, version) = (resource_info['vendor'], resource_info['name'], resource_info['version'])
+            resource = CatalogueResource.objects.get(vendor=vendor, short_name=name, version=version)
+            base_dir = catalogue_utils.wgt_deployer.get_base_dir(vendor, name, version)
+            zf.write(os.path.join(base_dir, resource.template_uri), resource_info['src'])
         zf.close()
         wgt_file = WgtFile(f)
 
-        market_managers = get_market_managers(request.user)
-        try:
-            market_managers['local'].publish(None, wgt_file, request.user, options, request)
-        except Exception, e:
-            return build_error_response(request, 502, unicode(e))
+        resource = get_local_catalogue().publish(None, wgt_file, request.user, options, request)
 
-        return HttpResponse(status=201)
+        return HttpResponse(json.dumps(resource.get_processed_info(request), ensure_ascii=False), status=201, content_type='application/json; charset=utf-8')
